@@ -15,7 +15,7 @@ import (
 	"github.com/derailed/k9s/internal/config/json"
 	"github.com/derailed/k9s/internal/slogs"
 	"github.com/derailed/k9s/internal/view/cmd"
-	"gopkg.in/yaml.v2"
+	"gopkg.in/yaml.v3"
 	"k8s.io/cli-runtime/pkg/genericclioptions"
 )
 
@@ -34,6 +34,11 @@ func NewConfig(ks data.KubeSettings) *Config {
 	}
 }
 
+// IsReadOnly returns true if K9s is running in read-only mode.
+func (c *Config) IsReadOnly() bool {
+	return c.K9s.IsReadOnly()
+}
+
 // ActiveClusterName returns the corresponding cluster name.
 func (c *Config) ActiveClusterName(contextName string) (string, error) {
 	ct, err := c.settings.GetContext(contextName)
@@ -181,16 +186,16 @@ func (c *Config) ActiveView() string {
 	if err != nil {
 		return data.DefaultView
 	}
-	cmd := ct.View.Active
+	v := ct.View.Active
 	if c.K9s.manualCommand != nil && *c.K9s.manualCommand != "" {
-		cmd = *c.K9s.manualCommand
+		v = *c.K9s.manualCommand
 		// We reset the manualCommand property because
 		// the command-line switch should only be considered once,
 		// on startup.
 		*c.K9s.manualCommand = ""
 	}
 
-	return cmd
+	return v
 }
 
 func (c *Config) ResetActiveView() {
@@ -284,14 +289,13 @@ func (c *Config) SaveFile(path string) error {
 		return err
 	}
 
-	cfg, err := yaml.Marshal(c)
-	if err != nil {
+	if err := data.SaveYAML(path, c); err != nil {
 		slog.Error("Unable to save K9s config file", slogs.Error, err)
 		return err
 	}
 
 	slog.Info("[CONFIG] Saving K9s config to disk", slogs.Path, path)
-	return os.WriteFile(path, cfg, data.DefaultFileMod)
+	return nil
 }
 
 // Validate the configuration.
