@@ -331,6 +331,9 @@ func loadPreferred(f Factory, m ResourceMetas) error {
 			if !isStandardGroup(r.GroupVersion) {
 				res.Categories = append(res.Categories, crdCat)
 			}
+			if isScalable(gvr) {
+				res.Categories = append(res.Categories, scaleCat)
+			}
 			m[gvr] = &res
 		}
 	}
@@ -342,6 +345,12 @@ func isStandardGroup(gv string) bool {
 	return stdGroups.Has(gv) || strings.Contains(gv, ".k8s.io")
 }
 
+func isScalable(gvr *client.GVR) bool {
+	ss := sets.New(client.DpGVR, client.StsGVR)
+
+	return ss.Has(gvr)
+}
+
 var deprecatedGVRs = sets.New(
 	client.NewGVR("v1/events"),
 	client.NewGVR("extensions/v1beta1/ingresses"),
