@@ -15,9 +15,7 @@ import (
 type DecoratorFunc func(string) string
 
 // AgeDecorator represents a timestamped as human column.
-var AgeDecorator = func(a string) string {
-	return toAgeHuman(a)
-}
+var AgeDecorator = toAgeHuman
 
 type Base struct {
 	vs         *config.ViewSetting
@@ -42,6 +40,7 @@ func (b *Base) doHeader(dh model1.Header) model1.Header {
 	return b.specs.Header(dh)
 }
 
+// SetViewSetting sets custom view settings if any.
 func (b *Base) SetViewSetting(vs *config.ViewSetting) {
 	var cols []string
 	b.vs = vs
