@@ -7,6 +7,8 @@ import (
 	"fmt"
 	"os"
 
+	"github.com/derailed/k9s/internal/config"
+	"github.com/derailed/k9s/internal/model1"
 	"github.com/derailed/tcell/v2"
 	"k8s.io/apimachinery/pkg/runtime"
 	"k8s.io/apimachinery/pkg/runtime/schema"
@@ -21,22 +23,24 @@ func (Dir) IsGeneric() bool {
 }
 
 // ColorerFunc colors a resource row.
-func (Dir) ColorerFunc() ColorerFunc {
-	return func(ns string, _ Header, re RowEvent) tcell.Color {
+func (Dir) ColorerFunc() model1.ColorerFunc {
+	return func(string, model1.Header, *model1.RowEvent) tcell.Color {
 		return tcell.ColorCadetBlue
 	}
 }
 
+func (Dir) SetViewSetting(*config.ViewSetting) {}
+
 // Header returns a header row.
-func (Dir) Header(ns string) Header {
-	return Header{
-		HeaderColumn{Name: "NAME"},
+func (Dir) Header(string) model1.Header {
+	return model1.Header{
+		model1.HeaderColumn{Name: "NAME"},
 	}
 }
 
 // Render renders a K8s resource to screen.
 // BOZO!! Pass in a row with pre-alloc fields??
-func (Dir) Render(o interface{}, ns string, r *Row) error {
+func (Dir) Render(o any, _ string, r *model1.Row) error {
 	d, ok := o.(DirRes)
 	if !ok {
 		return fmt.Errorf("expected DirRes, but got %T", o)
