@@ -345,8 +345,8 @@ func (c *Command) exec(p *cmd.Interpreter, gvr *client.GVR, comp model.Component
 	comp.SetCommand(p)
 
 	if clearStack {
-		cmd := contextRX.ReplaceAllString(p.GetLine(), "")
-		c.app.Config.SetActiveView(cmd)
+		v := contextRX.ReplaceAllString(p.GetLine(), "")
+		c.app.Config.SetActiveView(v)
 	}
 	if err := c.app.inject(comp, clearStack); err != nil {
 		return err
