@@ -15,7 +15,7 @@ import (
 func TestDeploy(t *testing.T) {
 	v := view.NewDeploy(client.DpGVR)
 
-	require.NoError(t, v.Init(makeCtx()))
+	require.NoError(t, v.Init(makeCtx(t)))
 	assert.Equal(t, "Deployments", v.Name())
 	assert.Len(t, v.Hints(), 16)
 }
