@@ -62,9 +62,9 @@ func NewLiveView(app *App, title string, m model.ResourceViewer) *LiveView {
 	return &v
 }
 
-func (v *LiveView) SetCommand(*cmd.Interpreter)      {}
-func (v *LiveView) SetFilter(string)                 {}
-func (v *LiveView) SetLabelFilter(map[string]string) {}
+func (*LiveView) SetCommand(*cmd.Interpreter)      {}
+func (*LiveView) SetFilter(string)                 {}
+func (*LiveView) SetLabelFilter(map[string]string) {}
 
 // Init initializes the viewer.
 func (v *LiveView) Init(_ context.Context) error {
@@ -129,7 +129,7 @@ func (v *LiveView) ResourceChanged(lines []string, matches fuzzy.Matches) {
 }
 
 // BufferChanged indicates the buffer was changed.
-func (v *LiveView) BufferChanged(_, _ string) {}
+func (*LiveView) BufferChanged(_, _ string) {}
 
 // BufferCompleted indicates input was accepted.
 func (v *LiveView) BufferCompleted(text, _ string) {
@@ -193,7 +193,7 @@ func (v *LiveView) editCmd(evt *tcell.EventKey) *tcell.EventKey {
 }
 
 // ToggleRefreshCmd is used for pausing the refreshing of data on config map and secrets.
-func (v *LiveView) toggleRefreshCmd(evt *tcell.EventKey) *tcell.EventKey {
+func (v *LiveView) toggleRefreshCmd(*tcell.EventKey) *tcell.EventKey {
 	v.autoRefresh = !v.autoRefresh
 	if v.autoRefresh {
 		v.Start()
@@ -216,9 +216,9 @@ func (v *LiveView) keyboard(evt *tcell.EventKey) *tcell.EventKey {
 
 // StylesChanged notifies the skin changed.
 func (v *LiveView) StylesChanged(s *config.Styles) {
-	v.SetBackgroundColor(v.app.Styles.BgColor())
-	v.text.SetTextColor(v.app.Styles.FgColor())
-	v.SetBorderFocusColor(v.app.Styles.Frame().Border.FocusColor.Color())
+	v.SetBackgroundColor(s.BgColor())
+	v.text.SetTextColor(s.FgColor())
+	v.SetBorderFocusColor(s.Frame().Border.FocusColor.Color())
 }
 
 // Actions returns menu actions.
@@ -264,7 +264,7 @@ func (v *LiveView) Hints() model.MenuHints {
 }
 
 // ExtraHints returns additional hints.
-func (v *LiveView) ExtraHints() map[string]string {
+func (*LiveView) ExtraHints() map[string]string {
 	return nil
 }
 
@@ -332,7 +332,7 @@ func (v *LiveView) prevCmd(evt *tcell.EventKey) *tcell.EventKey {
 	return nil
 }
 
-func (v *LiveView) filterCmd(evt *tcell.EventKey) *tcell.EventKey {
+func (v *LiveView) filterCmd(*tcell.EventKey) *tcell.EventKey {
 	v.model.Filter(v.cmdBuff.GetText())
 	v.cmdBuff.SetActive(false)
 	v.updateTitle()
@@ -349,7 +349,7 @@ func (v *LiveView) activateCmd(evt *tcell.EventKey) *tcell.EventKey {
 	return nil
 }
 
-func (v *LiveView) eraseCmd(evt *tcell.EventKey) *tcell.EventKey {
+func (v *LiveView) eraseCmd(*tcell.EventKey) *tcell.EventKey {
 	if !v.cmdBuff.IsActive() {
 		return nil
 	}
@@ -374,7 +374,7 @@ func (v *LiveView) resetCmd(evt *tcell.EventKey) *tcell.EventKey {
 	return nil
 }
 
-func (v *LiveView) saveCmd(evt *tcell.EventKey) *tcell.EventKey {
+func (v *LiveView) saveCmd(*tcell.EventKey) *tcell.EventKey {
 	name := fmt.Sprintf("%s--%s", strings.Replace(v.model.GetPath(), "/", "-", 1), strings.ToLower(v.title))
 	if _, err := saveYAML(v.app.Config.K9s.ContextScreenDumpDir(), name, sanitizeEsc(v.text.GetText(true))); err != nil {
 		v.app.Flash().Err(err)
@@ -394,9 +394,12 @@ func (v *LiveView) updateTitle() {
 		fmat = fmt.Sprintf(liveViewTitleFmt, v.title, v.model.GetPath())
 	}
 
-	buff := v.cmdBuff.GetText()
+	var (
+		buff   = v.cmdBuff.GetText()
+		styles = v.app.Styles.Frame()
+	)
 	if buff == "" {
-		v.SetTitle(ui.SkinTitle(fmat, v.app.Styles.Frame()))
+		v.SetTitle(ui.SkinTitle(fmat, &styles))
 		return
 	}
 
@@ -404,5 +407,5 @@ func (v *LiveView) updateTitle() {
 		buff += fmt.Sprintf("[%d:%d]", v.currentRegion+1, v.maxRegions)
 	}
 	fmat += fmt.Sprintf(ui.SearchFmt, buff)
-	v.SetTitle(ui.SkinTitle(fmat, v.app.Styles.Frame()))
+	v.SetTitle(ui.SkinTitle(fmat, &styles))
 }
